@@ -8,9 +8,11 @@ find . \( -type f -o -type l \) \
    -not -path "./deb-dist/*" \
    -not -path "./blib/*" \
    -not -path './.git/*' \
+   -not -path './tarball/*' \
    -not -path ./Makefile \
    -not -name MANIFEST \
    -not -name pm_to_blib \
    -not -name testDb \
+   -not -name 'libapp-recordstream*.deb' \
    | sed -e 's/^\.\///' | sort >MANIFEST
 
